@@ -155,7 +155,7 @@ class TeleBot:
                 if not none_stop:
                     self.__stop_polling.set()
                     logger.info("TeleBot: Exception occurred. Stopping.")
-                logger.error(e.message)
+                logger.error(e)
 
         logger.info('TeleBot: Stopped polling.')
 
@@ -372,7 +372,7 @@ class TeleBot:
             return TeleBot.extract_command(message.text) in message_handler['commands']
         if 'regexp' in message_handler and message.content_type == 'text' and re.search(message_handler['regexp'],
                                                                                         message.text):
-            return False
+            return True
         if 'lambda' in message_handler:
             return message_handler['lambda'](message)
         return False
